@@ -10,22 +10,23 @@ import (
 
 	"github.com/blang/semver"
 	"github.com/ghodss/yaml"
-	"github.com/stretchr/testify/require"
-	appsv1 "k8s.io/api/apps/v1"
-	corev1 "k8s.io/api/core/v1"
-	rbacv1 "k8s.io/api/rbac/v1"
-	"k8s.io/apiextensions-apiserver/pkg/apis/apiextensions"
-	k8serrors "k8s.io/apimachinery/pkg/api/errors"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/util/wait"
-
+	configv1client "github.com/openshift/client-go/config/clientset/versioned/typed/config/v1"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/client/clientset/versioned"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/install"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry/resolver"
+	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/comparison"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/operatorclient"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/version"
+	"github.com/stretchr/testify/require"
+	appsv1 "k8s.io/api/apps/v1"
+	corev1 "k8s.io/api/core/v1"
+	"k8s.io/apiextensions-apiserver/pkg/apis/apiextensions"
+	k8serrors "k8s.io/apimachinery/pkg/api/errors"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/util/wait"
+	"k8s.io/client-go/tools/clientcmd"
 )
 
 var doubleInstance = int32(2)
@@ -307,7 +308,13 @@ func subscriptionStateAtLatestChecker(subscription *v1alpha1.Subscription) bool
 }
 
 func subscriptionHasInstallPlanChecker(subscription *v1alpha1.Subscription) bool {
-	return subscription.Status.Install != nil
+	return subscription.Status.InstallPlanRef != nil
+}
+
+func subscriptionHasInstallPlanDifferentChecker(currentInstallPlanName string) subscriptionStateChecker {
+	return func(subscription *v1alpha1.Subscription) bool {
+		return subscriptionHasInstallPlanChecker(subscription) && subscription.Status.InstallPlanRef.Name != currentInstallPlanName
+	}
 }
 
 func subscriptionStateNoneChecker(subscription *v1alpha1.Subscription) bool {
@@ -327,6 +334,19 @@ func subscriptionHasCurrentCSV(currentCSV string) subscriptionStateChecker {
 	}
 }
 
+func subscriptionHasCondition(condType v1alpha1.SubscriptionConditionType, status corev1.ConditionStatus, reason, message string) subscriptionStateChecker {
+	return func(subscription *v1alpha1.Subscription) bool {
+		cond := subscription.Status.GetCondition(condType)
+		if cond.Status == status && cond.Reason == reason && cond.Message == message {
+			fmt.Printf("subscription condition met %v\n", cond)
+			return true
+		}
+
+		fmt.Printf("subscription condition not met: %v\n", cond)
+		return false
+	}
+}
+
 func fetchSubscription(t *testing.T, crc versioned.Interface, namespace, name string, checker subscriptionStateChecker) (*v1alpha1.Subscription, error) {
 	var fetchedSubscription *v1alpha1.Subscription
 	var err error
@@ -457,11 +477,6 @@ func TestCreateNewSubscriptionNotInstalled(t *testing.T) {
 
 	_, err = fetchCSV(t, crc, subscription.Status.CurrentCSV, testNamespace, buildCSVConditionChecker(v1alpha1.CSVPhaseSucceeded))
 	require.NoError(t, err)
-
-	// Fetch subscription again to check for unnecessary control loops
-	sameSubscription, err := fetchSubscription(t, crc, testNamespace, testSubscriptionName, subscriptionStateAtLatestChecker)
-	require.NoError(t, err)
-	compareResources(t, subscription, sameSubscription)
 }
 
 //   I. Creating a new subscription
@@ -489,11 +504,6 @@ func TestCreateNewSubscriptionExistingCSV(t *testing.T) {
 	require.NotNil(t, subscription)
 	_, err = fetchCSV(t, crc, subscription.Status.CurrentCSV, testNamespace, buildCSVConditionChecker(v1alpha1.CSVPhaseSucceeded))
 	require.NoError(t, err)
-
-	// check for unnecessary control loops
-	sameSubscription, err := fetchSubscription(t, crc, testNamespace, testSubscriptionName, subscriptionStateAtLatestChecker)
-	require.NoError(t, err)
-	compareResources(t, subscription, sameSubscription)
 }
 
 func TestSubscriptionSkipRange(t *testing.T) {
@@ -861,151 +871,327 @@ func TestSubscriptionUpdatesMultipleIntermediates(t *testing.T) {
 	// TODO: check installplans, subscription status, etc
 }
 
-// TestSubscriptionUpdatesExistingInstallPlan ensures that an existing InstallPlan
-//  has the appropriate approval requirement from Subscription.
-func TestSubscriptionUpdatesExistingInstallPlan(t *testing.T) {
+// TestSubscriptionStatusMissingTargetCatalogSource ensures that a Subscription has the appropriate status condition when
+// its target catalog is missing.
+//
+// Steps:
+// 1. Generate an initial CatalogSource in the target namespace
+// 2. Generate Subscription, "sub", targetting non-existent CatalogSource, "missing"
+// 3. Wait for sub status to show SubscriptionCatalogSourcesUnhealthy with status True, reason CatalogSourcesUpdated, and appropriate missing message
+// 4. Update sub's spec to target the "mysubscription"
+// 5. Wait for sub's status to show SubscriptionCatalogSourcesUnhealthy with status False, reason AllCatalogSourcesHealthy, and reason "all available catalogsources are healthy"
+// 6. Wait for sub to succeed
+func TestSubscriptionStatusMissingTargetCatalogSource(t *testing.T) {
 	defer cleaner.NotifyTestComplete(t, true)
 
-	// Create CSV
-	packageName := genName("nginx-")
-	stableChannel := "stable"
-
-	namedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-	csvA := newCSV("nginx-a", testNamespace, "", semver.MustParse("0.1.0"), nil, nil, namedStrategy)
-	csvB := newCSV("nginx-b", testNamespace, "nginx-a", semver.MustParse("0.2.0"), nil, nil, namedStrategy)
-
-	// Create PackageManifests
-	manifests := []registry.PackageManifest{
-		{
-			PackageName: packageName,
-			Channels: []registry.PackageChannel{
-				{Name: stableChannel, CurrentCSVName: csvB.GetName()},
-			},
-			DefaultChannelName: stableChannel,
-		},
-	}
-
-	// Create the CatalogSource with just one version
 	c := newKubeClient(t)
 	crc := newCRClient(t)
-	catalogSourceName := genName("mock-nginx-")
-	_, cleanupCatalogSource := createInternalCatalogSource(t, c, crc, catalogSourceName, testNamespace, manifests, nil, []v1alpha1.ClusterServiceVersion{csvA, csvB})
-	defer cleanupCatalogSource()
+	defer func() {
+		require.NoError(t, crc.OperatorsV1alpha1().Subscriptions(testNamespace).DeleteCollection(&metav1.DeleteOptions{}, metav1.ListOptions{}))
+	}()
+	require.NoError(t, initCatalog(t, c, crc))
 
-	// Attempt to get the catalog source before creating install plan
-	_, err := fetchCatalogSource(t, crc, catalogSourceName, testNamespace, catalogSourceRegistryPodSynced)
+	missingName := "missing"
+	cleanup := createSubscriptionForCatalog(t, crc, testNamespace, testSubscriptionName, missingName, testPackageName, betaChannel, "", v1alpha1.ApprovalAutomatic)
+	defer cleanup()
+
+	sub, err := fetchSubscription(t, crc, testNamespace, testSubscriptionName, subscriptionHasCondition(v1alpha1.SubscriptionCatalogSourcesUnhealthy, corev1.ConditionTrue, v1alpha1.UnhealthyCatalogSourceFound, fmt.Sprintf("targeted catalogsource %s/%s missing", testNamespace, missingName)))
+	require.NoError(t, err)
+	require.NotNil(t, sub)
+
+	// Update sub to target an existing CatalogSource
+	sub.Spec.CatalogSource = catalogSourceName
+	_, err = crc.OperatorsV1alpha1().Subscriptions(testNamespace).Update(sub)
 	require.NoError(t, err)
 
-	// Create a subscription to just get an InstallPlan for csvB
-	subscriptionName := genName("sub-nginx-")
-	createSubscriptionForCatalog(t, crc, testNamespace, subscriptionName, catalogSourceName, packageName, stableChannel, csvB.GetName(), v1alpha1.ApprovalAutomatic)
-
-	// Wait for csvB to be installed
-	_, err = awaitCSV(t, crc, testNamespace, csvB.GetName(), csvSucceededChecker)
+	// Wait for SubscriptionCatalogSourcesUnhealthy to be false
+	_, err = fetchSubscription(t, crc, testNamespace, testSubscriptionName, subscriptionHasCondition(v1alpha1.SubscriptionCatalogSourcesUnhealthy, corev1.ConditionFalse, v1alpha1.AllCatalogSourcesHealthy, "all available catalogsources are healthy"))
 	require.NoError(t, err)
 
-	subscription, err := fetchSubscription(t, crc, testNamespace, subscriptionName, subscriptionHasInstallPlanChecker)
-	fetchedInstallPlan, err := fetchInstallPlan(t, crc, subscription.Status.InstallPlanRef.Name, buildInstallPlanPhaseCheckFunc(v1alpha1.InstallPlanPhaseComplete))
-
-	// Delete this subscription
-	err = crc.OperatorsV1alpha1().Subscriptions(testNamespace).DeleteCollection(metav1.NewDeleteOptions(0), metav1.ListOptions{})
-	require.NoError(t, err)
-	// Delete orphaned csvB
-	require.NoError(t, crc.OperatorsV1alpha1().ClusterServiceVersions(testNamespace).Delete(csvB.GetName(), &metav1.DeleteOptions{}))
-
-	// Create an InstallPlan for csvB
-	ip := &v1alpha1.InstallPlan{
-		ObjectMeta: metav1.ObjectMeta{
-			GenerateName: "install-",
-			Namespace:    testNamespace,
-		},
-		Spec: v1alpha1.InstallPlanSpec{
-			ClusterServiceVersionNames: []string{csvB.GetName()},
-			Approval:                   v1alpha1.ApprovalAutomatic,
-			Approved:                   false,
-		},
-	}
-	ip2, err := crc.OperatorsV1alpha1().InstallPlans(testNamespace).Create(ip)
-	require.NoError(t, err)
-
-	ip2.Status = v1alpha1.InstallPlanStatus{
-		Plan:           fetchedInstallPlan.Status.Plan,
-		CatalogSources: []string{catalogSourceName},
-	}
-
-	_, err = crc.OperatorsV1alpha1().InstallPlans(testNamespace).UpdateStatus(ip2)
-	require.NoError(t, err)
-
-	subscriptionName = genName("sub-nginx-")
-	cleanupSubscription := createSubscriptionForCatalog(t, crc, testNamespace, subscriptionName, catalogSourceName, packageName, stableChannel, csvA.GetName(), v1alpha1.ApprovalManual)
-	defer cleanupSubscription()
-
-	subscription, err = fetchSubscription(t, crc, testNamespace, subscriptionName, subscriptionHasInstallPlanChecker)
-	require.NoError(t, err)
-	require.NotNil(t, subscription)
-
-	installPlanName := subscription.Status.Install.Name
-
-	// Wait for InstallPlan to be status: Complete before checking resource presence
-	requiresApprovalChecker := buildInstallPlanPhaseCheckFunc(v1alpha1.InstallPlanPhaseRequiresApproval)
-	fetchedInstallPlan, err = fetchInstallPlan(t, crc, installPlanName, requiresApprovalChecker)
-	require.NoError(t, err)
-
-	// Approve the installplan and wait for csvA to be installed
-	fetchedInstallPlan.Spec.Approved = true
-	_, err = crc.OperatorsV1alpha1().InstallPlans(testNamespace).Update(fetchedInstallPlan)
-	require.NoError(t, err)
-
-	// Wait for csvA to be installed
-	_, err = awaitCSV(t, crc, testNamespace, csvA.GetName(), csvSucceededChecker)
-	require.NoError(t, err)
-
-	// Wait for the subscription to begin upgrading to csvB
-	subscription, err = fetchSubscription(t, crc, testNamespace, subscriptionName, subscriptionStateUpgradePendingChecker)
-	require.NoError(t, err)
-
-	// Fetch existing csvB installPlan
-	fetchedInstallPlan, err = fetchInstallPlan(t, crc, subscription.Status.InstallPlanRef.Name, requiresApprovalChecker)
-	require.NoError(t, err)
-	require.Equal(t, ip2.GetName(), subscription.Status.InstallPlanRef.Name, "expected new installplan is the same with pre-exising one")
-
-	// Approve the installplan and wait for csvB to be installed
-	fetchedInstallPlan.Spec.Approved = true
-	_, err = crc.OperatorsV1alpha1().InstallPlans(testNamespace).Update(fetchedInstallPlan)
-	require.NoError(t, err)
-
-	// Wait for csvB to be installed
-	_, err = awaitCSV(t, crc, testNamespace, csvB.GetName(), csvSucceededChecker)
+	// Wait for success
+	_, err = fetchSubscription(t, crc, testNamespace, testSubscriptionName, subscriptionStateAtLatestChecker)
 	require.NoError(t, err)
 }
 
-func TestCreateNewSubscriptionWithDependencies(t *testing.T) {
+// TestSubscriptionInstallPlanStatus ensures that a Subscription has the appropriate status conditions for possible referenced
+// InstallPlan states.
+//
+// Steps:
+// 1. Create namespace, ns
+// 2. Create CatalogSource, cs, in ns
+// 3. Create OperatorGroup, og, in ns selecting its own namespace
+// 4. Create Subscription to a package of cs in ns, sub
+// 5. Wait for the package from sub to install successfully with no remaining InstallPlan status conditions
+// 6. Store conditions for later comparision
+// 7. Get the InstallPlan
+// 8. Set the InstallPlan's approval mode to Manual
+// 9. Set the InstallPlan's phase to None
+// 10. Wait for sub to have status condition SubscriptionInstallPlanPending true and reason InstallPlanNotYetReconciled
+// 11. Get the latest IntallPlan and set the phase to InstallPlanPhaseRequiresApproval
+// 12. Wait for sub to have status condition SubscriptionInstallPlanPending true and reason RequiresApproval
+// 13. Get the latest InstallPlan and set the phase to InstallPlanPhaseInstalling
+// 14. Wait for sub to have status condition SubscriptionInstallPlanPending true and reason Installing
+// 15. Get the latest InstallPlan and set the phase to InstallPlanPhaseFailed and remove all status conditions
+// 16. Wait for sub to have status condition SubscriptionInstallPlanFailed true and reason InstallPlanFailed
+// 17. Get the latest InstallPlan and set status condition of type Installed to false with reason InstallComponentFailed
+// 18. Wait for sub to have status condition SubscriptionInstallPlanFailed true and reason InstallComponentFailed
+// 19. Delete the referenced InstallPlan
+// 20. Wait for sub to have status condition SubscriptionInstallPlanMissing true
+// 21. Ensure original non-InstallPlan status conditions remain after InstallPlan transitions
+func TestSubscriptionInstallPlanStatus(t *testing.T) {
 	defer cleaner.NotifyTestComplete(t, true)
 
+	c := newKubeClient(t)
+	crc := newCRClient(t)
+
+	// Create namespace ns
+	ns := &corev1.Namespace{
+		ObjectMeta: metav1.ObjectMeta{
+			Name: genName("ns-"),
+		},
+	}
+	_, err := c.KubernetesInterface().CoreV1().Namespaces().Create(ns)
+	require.NoError(t, err)
+	defer func() {
+		require.NoError(t, c.KubernetesInterface().CoreV1().Namespaces().Delete(ns.GetName(), &metav1.DeleteOptions{}))
+	}()
+
+	// Create CatalogSource, cs, in ns
+	pkgName := genName("pkg-")
+	channelName := genName("channel-")
+	strategy := newNginxInstallStrategy(pkgName, nil, nil)
+	crd := newCRD(pkgName)
+	csv := newCSV(pkgName, ns.GetName(), "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, strategy)
+	manifests := []registry.PackageManifest{
+		{
+			PackageName: pkgName,
+			Channels: []registry.PackageChannel{
+				{Name: channelName, CurrentCSVName: csv.GetName()},
+			},
+			DefaultChannelName: channelName,
+		},
+	}
+	catalogName := genName("catalog-")
+	_, cleanupCatalogSource := createInternalCatalogSource(t, c, crc, catalogName, ns.GetName(), manifests, []apiextensions.CustomResourceDefinition{crd}, []v1alpha1.ClusterServiceVersion{csv})
+	defer cleanupCatalogSource()
+	_, err = fetchCatalogSource(t, crc, catalogName, ns.GetName(), catalogSourceRegistryPodSynced)
+	require.NoError(t, err)
+
+	// Create OperatorGroup, og, in ns selecting its own namespace
+	og := newOperatorGroup(ns.GetName(), genName("og-"), nil, nil, []string{ns.GetName()}, false)
+	_, err = crc.OperatorsV1().OperatorGroups(og.GetNamespace()).Create(og)
+	require.NoError(t, err)
+	defer func() {
+		require.NoError(t, crc.OperatorsV1().OperatorGroups(og.GetNamespace()).Delete(og.GetName(), &metav1.DeleteOptions{}))
+	}()
+
+	// Create Subscription to a package of cs in ns, sub
+	subName := genName("sub-")
+	defer createSubscriptionForCatalog(t, crc, ns.GetName(), subName, catalogName, pkgName, channelName, pkgName, v1alpha1.ApprovalAutomatic)()
+
+	// Wait for the package from sub to install successfully with no remaining InstallPlan status conditions
+	sub, err := fetchSubscription(t, crc, ns.GetName(), subName, func(s *v1alpha1.Subscription) bool {
+		for _, cond := range s.Status.Conditions {
+			switch cond.Type {
+			case v1alpha1.SubscriptionInstallPlanMissing, v1alpha1.SubscriptionInstallPlanPending, v1alpha1.SubscriptionInstallPlanFailed:
+				return false
+			}
+		}
+		return subscriptionStateAtLatestChecker(s)
+	})
+	require.NoError(t, err)
+	require.NotNil(t, sub)
+
+	// Store conditions for later comparision
+	conds := sub.Status.Conditions
+
+	// Get the InstallPlan
+	ref := sub.Status.InstallPlanRef
+	require.NotNil(t, ref)
+	plan, err := crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).Get(ref.Name, metav1.GetOptions{})
+	require.NoError(t, err)
+
+	// Set the InstallPlan's approval mode to Manual
+	plan.Spec.Approval = v1alpha1.ApprovalManual
+	plan.Spec.Approved = false
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).Update(plan)
+	require.NoError(t, err)
+
+	// Set the InstallPlan's phase to None
+	plan.Status.Phase = v1alpha1.InstallPlanPhaseNone
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).UpdateStatus(plan)
+	require.NoError(t, err)
+
+	// Wait for sub to have status condition SubscriptionInstallPlanPending true and reason InstallPlanNotYetReconciled
+	sub, err = fetchSubscription(t, crc, ns.GetName(), subName, func(s *v1alpha1.Subscription) bool {
+		cond := s.Status.GetCondition(v1alpha1.SubscriptionInstallPlanPending)
+		return cond.Status == corev1.ConditionTrue && cond.Reason == v1alpha1.InstallPlanNotYetReconciled
+	})
+	require.NoError(t, err)
+
+	// Get the latest InstallPlan and set the phase to InstallPlanPhaseRequiresApproval
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).Get(ref.Name, metav1.GetOptions{})
+	require.NoError(t, err)
+	plan.Status.Phase = v1alpha1.InstallPlanPhaseRequiresApproval
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).UpdateStatus(plan)
+	require.NoError(t, err)
+
+	// Wait for sub to have status condition SubscriptionInstallPlanPending true and reason RequiresApproval
+	sub, err = fetchSubscription(t, crc, ns.GetName(), subName, func(s *v1alpha1.Subscription) bool {
+		cond := s.Status.GetCondition(v1alpha1.SubscriptionInstallPlanPending)
+		return cond.Status == corev1.ConditionTrue && cond.Reason == string(v1alpha1.InstallPlanPhaseRequiresApproval)
+	})
+	require.NoError(t, err)
+
+	// Get the latest InstallPlan and set the phase to InstallPlanPhaseInstalling
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).Get(ref.Name, metav1.GetOptions{})
+	require.NoError(t, err)
+	plan.Status.Phase = v1alpha1.InstallPlanPhaseInstalling
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).UpdateStatus(plan)
+	require.NoError(t, err)
+
+	// Wait for sub to have status condition SubscriptionInstallPlanPending true and reason Installing
+	sub, err = fetchSubscription(t, crc, ns.GetName(), subName, func(s *v1alpha1.Subscription) bool {
+		cond := s.Status.GetCondition(v1alpha1.SubscriptionInstallPlanPending)
+		return cond.Status == corev1.ConditionTrue && cond.Reason == string(v1alpha1.InstallPlanPhaseInstalling)
+	})
+	require.NoError(t, err)
+
+	// Get the latest InstallPlan and set the phase to InstallPlanPhaseFailed and remove all status conditions
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).Get(ref.Name, metav1.GetOptions{})
+	require.NoError(t, err)
+	plan.Status.Phase = v1alpha1.InstallPlanPhaseFailed
+	plan.Status.Conditions = nil
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).UpdateStatus(plan)
+	require.NoError(t, err)
+
+	// Wait for sub to have status condition SubscriptionInstallPlanFailed true and reason InstallPlanFailed
+	sub, err = fetchSubscription(t, crc, ns.GetName(), subName, func(s *v1alpha1.Subscription) bool {
+		cond := s.Status.GetCondition(v1alpha1.SubscriptionInstallPlanFailed)
+		return cond.Status == corev1.ConditionTrue && cond.Reason == v1alpha1.InstallPlanFailed
+	})
+	require.NoError(t, err)
+
+	// Get the latest InstallPlan and set status condition of type Installed to false with reason InstallComponentFailed
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).Get(ref.Name, metav1.GetOptions{})
+	require.NoError(t, err)
+	plan.Status.Phase = v1alpha1.InstallPlanPhaseFailed
+	failedCond := plan.Status.GetCondition(v1alpha1.InstallPlanInstalled)
+	failedCond.Status = corev1.ConditionFalse
+	failedCond.Reason = v1alpha1.InstallPlanReasonComponentFailed
+	plan.Status.SetCondition(failedCond)
+	plan, err = crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).UpdateStatus(plan)
+	require.NoError(t, err)
+
+	// Wait for sub to have status condition SubscriptionInstallPlanFailed true and reason InstallComponentFailed
+	sub, err = fetchSubscription(t, crc, ns.GetName(), subName, func(s *v1alpha1.Subscription) bool {
+		cond := s.Status.GetCondition(v1alpha1.SubscriptionInstallPlanFailed)
+		return cond.Status == corev1.ConditionTrue && cond.Reason == string(v1alpha1.InstallPlanReasonComponentFailed)
+	})
+	require.NoError(t, err)
+
+	// Delete the referenced InstallPlan
+	require.NoError(t, crc.OperatorsV1alpha1().InstallPlans(ref.Namespace).Delete(ref.Name, &metav1.DeleteOptions{}))
+
+	// Wait for sub to have status condition SubscriptionInstallPlanMissing true
+	sub, err = fetchSubscription(t, crc, ns.GetName(), subName, func(s *v1alpha1.Subscription) bool {
+		return s.Status.GetCondition(v1alpha1.SubscriptionInstallPlanMissing).Status == corev1.ConditionTrue
+	})
+	require.NoError(t, err)
+	require.NotNil(t, sub)
+
+	// Ensure original non-InstallPlan status conditions remain after InstallPlan transitions
+	hashEqual := comparison.NewHashEqualitor()
+	for _, cond := range conds {
+		switch condType := cond.Type; condType {
+		case v1alpha1.SubscriptionInstallPlanPending, v1alpha1.SubscriptionInstallPlanFailed:
+			require.FailNowf(t, "failed", "subscription contains unexpected installplan condition: %v", cond)
+		case v1alpha1.SubscriptionInstallPlanMissing:
+			require.Equal(t, v1alpha1.ReferencedInstallPlanNotFound, cond.Reason)
+		default:
+			require.True(t, hashEqual(cond, sub.Status.GetCondition(condType)), "non-installplan status condition changed")
+		}
+	}
+}
+
+func TestCreateNewSubscriptionWithPodConfig(t *testing.T) {
+	defer cleaner.NotifyTestComplete(t, true)
+
+	newConfigClient := func(t *testing.T) configv1client.ConfigV1Interface {
+		config, err := clientcmd.BuildConfigFromFlags("", *kubeConfigPath)
+		require.NoError(t, err)
+
+		client, err := configv1client.NewForConfig(config)
+		require.NoError(t, err)
+
+		return client
+	}
+
+	proxyEnvVarFunc := func(t *testing.T, client configv1client.ConfigV1Interface) []corev1.EnvVar {
+		proxy, getErr := client.Proxies().Get("cluster", metav1.GetOptions{})
+		if getErr != nil {
+			if !k8serrors.IsNotFound(getErr) {
+				require.NoError(t, getErr)
+			}
+
+			return nil
+		}
+
+		require.NotNil(t, proxy)
+		proxyEnv := []corev1.EnvVar{}
+
+		if proxy.Status.HTTPProxy != "" {
+			proxyEnv = append(proxyEnv, corev1.EnvVar{
+				Name:  "HTTP_PROXY",
+				Value: proxy.Status.HTTPProxy,
+			})
+		}
+
+		if proxy.Status.HTTPSProxy != "" {
+			proxyEnv = append(proxyEnv, corev1.EnvVar{
+				Name:  "HTTPS_PROXY",
+				Value: proxy.Status.HTTPSProxy,
+			})
+		}
+
+		if proxy.Status.NoProxy != "" {
+			proxyEnv = append(proxyEnv, corev1.EnvVar{
+				Name:  "NO_PROXY",
+				Value: proxy.Status.NoProxy,
+			})
+		}
+
+		return proxyEnv
+	}
+
 	kubeClient := newKubeClient(t)
 	crClient := newCRClient(t)
+	config := newConfigClient(t)
+
+	podEnv := []corev1.EnvVar{
+		corev1.EnvVar{
+			Name:  "MY_ENV_VARIABLE1",
+			Value: "value1",
+		},
+		corev1.EnvVar{
+			Name:  "MY_ENV_VARIABLE2",
+			Value: "value2",
+		},
+	}
+	podConfig := v1alpha1.SubscriptionConfig{
+		Env: podEnv,
+	}
 
 	permissions := deploymentPermissions(t)
-
-	catsrc, subSpec, catsrcCleanup := newCatalogSourceWithDependencies(t, kubeClient, crClient, "podconfig", testNamespace, permissions)
+	catsrc, subSpec, catsrcCleanup := newCatalogSource(t, kubeClient, crClient, "podconfig", testNamespace, permissions)
 	defer catsrcCleanup()
 
 	// Ensure that the catalog source is resolved before we create a subscription.
 	_, err := fetchCatalogSource(t, crClient, catsrc.GetName(), testNamespace, catalogSourceRegistryPodSynced)
 	require.NoError(t, err)
 
-	// Create duplicates of the CatalogSource
-	for i := 0; i < 10; i++ {
-		duplicateCatsrc, _, duplicateCatSrcCleanup := newCatalogSourceWithDependencies(t, kubeClient, crClient, "podconfig", testNamespace, permissions)
-		defer duplicateCatSrcCleanup()
-
-		// Ensure that the catalog source is resolved before we create a subscription.
-		_, err = fetchCatalogSource(t, crClient, duplicateCatsrc.GetName(), testNamespace, catalogSourceRegistryPodSynced)
-		require.NoError(t, err)
-	}
-
-	// Create a subscription that has a dependency
 	subscriptionName := genName("podconfig-sub-")
+	subSpec.Config = podConfig
 	cleanupSubscription := createSubscriptionForCatalogWithSpec(t, crClient, testNamespace, subscriptionName, subSpec)
 	defer cleanupSubscription()
 
@@ -1013,98 +1199,16 @@ func TestCreateNewSubscriptionWithDependencies(t *testing.T) {
 	require.NoError(t, err)
 	require.NotNil(t, subscription)
 
-	// Check that a single catalog source was used to resolve the InstallPlan
-	installPlan, err := fetchInstallPlan(t, crClient, subscription.Status.InstallPlanRef.Name, buildInstallPlanPhaseCheckFunc(v1alpha1.InstallPlanPhaseComplete))
+	csv, err := fetchCSV(t, crClient, subscription.Status.CurrentCSV, testNamespace, buildCSVConditionChecker(v1alpha1.CSVPhaseSucceeded))
 	require.NoError(t, err)
-	require.Len(t, installPlan.Status.CatalogSources, 1)
 
+	proxyEnv := proxyEnvVarFunc(t, config)
+	expected := podEnv
+	expected = append(expected, proxyEnv...)
+
+	checkDeploymentWithPodConfiguration(t, kubeClient, csv, podConfig.Env)
 }
 
-func deploymentPermissions(t *testing.T) []install.StrategyDeploymentPermissions {
-	// Generate permissions
-	serviceAccountName := genName("nginx-sa-")
-	permissions := []install.StrategyDeploymentPermissions{
-		{
-			ServiceAccountName: serviceAccountName,
-			Rules: []rbacv1.PolicyRule{
-				{
-					Verbs:     []string{rbacv1.VerbAll},
-					APIGroups: []string{rbacv1.APIGroupAll},
-					Resources: []string{rbacv1.ResourceAll}},
-			},
-		},
-	}
-
-	return permissions
-}
-
-func newCatalogSourceWithDependencies(t *testing.T, kubeclient operatorclient.ClientInterface, crclient versioned.Interface, prefix, namespace string, permissions []install.StrategyDeploymentPermissions) (catsrc *v1alpha1.CatalogSource, subscriptionSpec *v1alpha1.SubscriptionSpec, cleanup cleanupFunc) {
-	crdPlural := genName("ins")
-	crdName := crdPlural + ".cluster.com"
-
-	crd := apiextensions.CustomResourceDefinition{
-		ObjectMeta: metav1.ObjectMeta{
-			Name: crdName,
-		},
-		Spec: apiextensions.CustomResourceDefinitionSpec{
-			Group:   "cluster.com",
-			Version: "v1alpha1",
-			Names: apiextensions.CustomResourceDefinitionNames{
-				Plural:   crdPlural,
-				Singular: crdPlural,
-				Kind:     crdPlural,
-				ListKind: "list" + crdPlural,
-			},
-			Scope: "Namespaced",
-		},
-	}
-
-	prefixFunc := func(s string) string {
-		return fmt.Sprintf("%s-%s-", prefix, s)
-	}
-
-	// Create CSV
-	packageName1 := genName(prefixFunc("package"))
-	packageName2 := genName(prefixFunc("package"))
-	stableChannel := "stable"
-
-	namedStrategy := newNginxInstallStrategy(genName(prefixFunc("dep")), permissions, nil)
-	csvA := newCSV("nginx-req-dep", namespace, "", semver.MustParse("0.1.0"), nil, []apiextensions.CustomResourceDefinition{crd}, namedStrategy)
-	csvB := newCSV("nginx-dependency", namespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, namedStrategy)
-
-	// Create PackageManifests
-	manifests := []registry.PackageManifest{
-		{
-			PackageName: packageName1,
-			Channels: []registry.PackageChannel{
-				{Name: stableChannel, CurrentCSVName: csvA.GetName()},
-			},
-			DefaultChannelName: stableChannel,
-		},
-		{
-			PackageName: packageName2,
-			Channels: []registry.PackageChannel{
-				{Name: stableChannel, CurrentCSVName: csvB.GetName()},
-			},
-			DefaultChannelName: stableChannel,
-		},
-	}
-
-	catalogSourceName := genName(prefixFunc("catsrc"))
-	catsrc, cleanup = createInternalCatalogSource(t, kubeclient, crclient, catalogSourceName, namespace, manifests, []apiextensions.CustomResourceDefinition{crd}, []v1alpha1.ClusterServiceVersion{csvA, csvB})
-	require.NotNil(t, catsrc)
-	require.NotNil(t, cleanup)
-
-	subscriptionSpec = &v1alpha1.SubscriptionSpec{
-		CatalogSource:          catsrc.GetName(),
-		CatalogSourceNamespace: catsrc.GetNamespace(),
-		Package:                packageName1,
-		Channel:                stableChannel,
-		StartingCSV:            csvA.GetName(),
-		InstallPlanApproval:    v1alpha1.ApprovalAutomatic,
-	}
-	return
-}
 func checkDeploymentWithPodConfiguration(t *testing.T, client operatorclient.ClientInterface, csv *v1alpha1.ClusterServiceVersion, envVar []corev1.EnvVar) {
 	resolver := install.StrategyResolver{}
 
@@ -1180,11 +1284,13 @@ func updateInternalCatalog(t *testing.T, c operatorclient.ClientInterface, crc v
 
 	// wait for catalog to update
 	_, err = fetchCatalogSource(t, crc, catalogSourceName, testNamespace, func(catalog *v1alpha1.CatalogSource) bool {
-		if catalog.Status.LastSync != fetchedInitialCatalog.Status.LastSync && catalog.Status.ConfigMapResource.ResourceVersion != fetchedInitialCatalog.Status.ConfigMapResource.ResourceVersion {
+		before := fetchedInitialCatalog.Status.ConfigMapResource
+		after := catalog.Status.ConfigMapResource
+		if after != nil && after.LastUpdateTime.After(before.LastUpdateTime.Time) && after.ResourceVersion != before.ResourceVersion {
 			fmt.Println("catalog updated")
 			return true
 		}
-		fmt.Println("waiting for catalog pod to be available")
+		fmt.Printf("waiting for catalog pod %v to be available (after catalog update)\n", catalog.GetName())
 		return false
 	})
 	require.NoError(t, err)
